package cd.casic.ci.common.pipeline.pojo.element.market;

import cd.casic.ci.common.pipeline.NameAndValue;
import cd.casic.ci.common.pipeline.pojo.element.Element;
import cd.casic.ci.common.pipeline.pojo.element.ElementAdditionalOptions;
import cd.casic.ci.common.pipeline.pojo.transfer.PreStep;
import cd.casic.ci.common.pipeline.utils.TransferUtil;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.pojo.market
 * @Project：ops-pro
 * @name：MarketBuildAtomElement
 * @Date：2025/03/26 17:32
 * @Filename：MarketBuildAtomElement
 * @description：Todo
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Schema(title = "流水线模型-插件市场第三方构建环境类插件", description = MarketBuildAtomElement.classType)
public class MarketBuildAtomElement extends Element {
    public static final String classType = "marketBuild";

    @Schema(title = "任务名称", required = true)
    private String name = "任务名称由用户自己填写";

    @Schema(title = "id将由后台生成", required = false)
    private String id;

    @Schema(title = "状态", required = false)
    private String status;

    @Schema(title = "插件的唯一标识", required = true)
    private String atomCode;

    @Schema(title = "插件版本", required = false)
    private String version = "1.*";

    @Schema(title = "用户自定义ID", required = false)
    private String stepId;

    @Schema(title = "用户自定义环境变量（插件运行时写入环境）", required = false)
    private List<NameAndValue> customEnv;

    @Schema(title = "插件参数数据", required = true)
    private Map<String, Object> data = new HashMap<>();

    @Schema(title = "附加参数", required = false)
    private ElementAdditionalOptions additionalOptions;

    @Override
    public String getAtomCode() {
        return atomCode;
    }

    public PreStep transferYaml(JSONObject defaultValue) {
        Map<String, Object> input = (Map<String, Object>) data.getOrDefault("input", new HashMap<>());
        return new PreStep(
                name,
                stepId,
                getAtomCode() + "@" + version,
                TransferUtil.simplifyParams(defaultValue, input).isEmpty() ? null : TransferUtil.simplifyParams(defaultValue, input)
        );
    }

    @Override
    public String getClassType() {
        return classType;
    }
}
