package cd.casic.ci.log.api;


import cd.casic.ci.log.dal.pojo.QueryLogStatus;
import cd.casic.ci.log.dal.pojo.QueryLogs;
import cd.casic.ci.log.dal.pojo.enums.LogType;
import cd.casic.framework.commons.pojo.CommonResult;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.*;;


@RestController
@Tag(name = "用户-日志资源")
@RequestMapping("/user/logs")
public interface UserLogResource {
    @Operation(summary = "根据构建ID获取初始化所有日志")
    @GetMapping("/{projectId}/{pipelineId}/{buildId}/")
    CommonResult<QueryLogs> getInitLogs(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID)
                    String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId")
                    String projectId,
            @Parameter(description = "流水线ID", required = true)
            @PathVariable("pipelineId")
                    String pipelineId,
            @Parameter(description = "构建ID", required = true)
            @PathVariable("buildId")
                    String buildId,
            @Parameter(description = "是否包含调试日志", required = false)
            @RequestParam(value = "debug", defaultValue = "false")
                    boolean debug,
            @Parameter(description = "过滤日志级别", required = false)
            @RequestParam(value = "logType", defaultValue = "null")
            LogType logType,
            @Parameter(description = "对应elementId", required = false)
            @RequestParam(value = "tag")
                    String tag,
            @Parameter(description = "指定subTag", required = false)
            @RequestParam(value = "subTag")
                    String subTag,
            @Parameter(description = "对应jobId", required = false)
            @RequestParam(value = "jobId")
                    String jobId,
            @Parameter(description = "执行次数", required = false)
            @RequestParam(value = "executeCount")
                    int executeCount
    );

    @Operation(summary = "获取更多日志")
    @GetMapping("/{projectId}/{pipelineId}/{buildId}/more")
    CommonResult<QueryLogs> getMoreLogs(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID)
                    String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId")
                    String projectId,
            @Parameter(description = "流水线ID", required = true)
            @PathVariable("pipelineId")
                    String pipelineId,
            @Parameter(description = "构建ID", required = true)
            @PathVariable("buildId")
                    String buildId,
            @Parameter(description = "是否包含调试日志", required = false)
            @RequestParam(value = "debug", defaultValue = "false")
                    boolean debug,
            @Parameter(description = "过滤日志级别", required = false)
            @RequestParam(value = "logType", defaultValue = "null")
                    LogType logType,
            @Parameter(description = "日志行数", required = false)
            @RequestParam(value = "num", defaultValue = "100")
                    int num,
            @Parameter(description = "是否正序输出", required = false)
            @RequestParam(value = "fromStart", defaultValue = "true")
                    boolean fromStart,
            @Parameter(description = "起始行号", required = true)
            @RequestParam(value = "start")
                    long start,
            @Parameter(description = "结尾行号", required = true)
            @RequestParam(value = "end")
                    long end,
            @Parameter(description = "对应elementId", required = false)
            @RequestParam(value = "tag")
                    String tag,
            @Parameter(description = "指定subTag", required = false)
            @RequestParam(value = "subTag")
                    String subTag,
            @Parameter(description = "对应jobId", required = false)
            @RequestParam(value = "jobId")
                    String jobId,
            @Parameter(description = "执行次数", required = false)
            @RequestParam(value = "executeCount")
                    int executeCount
    );

    @Operation(summary = "获取某行后的日志")
    @GetMapping("/{projectId}/{pipelineId}/{buildId}/after")
    CommonResult<QueryLogs> getAfterLogs(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID)
                    String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId")
                    String projectId,
            @Parameter(description = "流水线ID", required = true)
            @PathVariable("pipelineId")
                    String pipelineId,
            @Parameter(description = "构建ID", required = true)
            @PathVariable("buildId")
                    String buildId,
            @Parameter(description = "起始行号", required = true)
            @RequestParam("start")
                    long start,
            @Parameter(description = "是否包含调试日志", required = false)
            @RequestParam(value = "debug",defaultValue = "false")
                    boolean debug,
            @Parameter(description = "过滤日志级别", required = false)
            @RequestParam(value = "logType",defaultValue = "null")
                    LogType logType,
            @Parameter(description = "对应elementId", required = false)
            @RequestParam("tag")
                    String tag,
            @Parameter(description = "指定subTag", required = false)
            @RequestParam("subTag")
                    String subTag,
            @Parameter(description = "对应jobId", required = false)
            @RequestParam("jobId")
                    String jobId,
            @Parameter(description = "执行次数", required = false)
            @RequestParam("executeCount")
                    int executeCount
    );

    @Operation(summary = "下载日志接口")
    @GetMapping("{projectId}/{pipelineId}/{buildId}/download")
    ResponseEntity downloadLogs(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID)
                    String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId")
                    String projectId,
            @Parameter(description = "流水线ID", required = true)
            @PathVariable("pipelineId")
                    String pipelineId,
            @Parameter(description = "构建ID", required = true)
            @PathVariable("buildId")
                    String buildId,
            @Parameter(description = "对应elementId", required = true)
            @RequestParam("tag")
                    String tag,
            @Parameter(description = "指定subTag", required = false)
            @RequestParam("subTag")
                    String subTag,
            @Parameter(description = "对应jobId", required = false)
            @RequestParam("jobId")
                    String jobId,
            @Parameter(description = "执行次数", required = false)
            @RequestParam("executeCount")
                    int executeCount,
            @Parameter(description = "文件名")
            @RequestParam("fileName")
                    String fileName
    );

    @Operation(summary = "获取插件的的日志状态")
    @GetMapping("/{projectId}/{pipelineId}/{buildId}/mode")
    CommonResult<QueryLogStatus> getLogMode(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID)
                    String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId")
                    String projectId,
            @Parameter(description = "流水线ID", required = true)
            @PathVariable("pipelineId")
                    String pipelineId,
            @Parameter(description = "构建ID", required = true)
            @PathVariable("buildId")
                    String buildId,
            @Parameter(description = "对应elementId", required = true)
            @RequestParam("tag")
                    String tag,
            @Parameter(description = "执行次数", required = false)
            @RequestParam("executeCount")
                    int executeCount
    );
}
