package cd.casic.ci.log.service;

import cd.casic.ci.log.log.LogStorageEvent;
import cd.casic.ci.log.log.LogOriginEvent;
import cd.casic.ci.log.log.LogStatusEvent;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.apache.logging.log4j.util.Strings;
import org.springframework.stereotype.Service;

/**
 * @author by mianbin
 * @Classname BuildLogListenerService
 * @Description TODO
 * @Date 2025/3/20 15:30
 */
@Slf4j
@Service
public class BuildLogListenerService {
    @Resource
    private LogService logService;

    @Resource
    private IndexService indexService;

    @Resource
    private BuildLogPrintService buildLogPrintService;

    public void handleEvent(LogOriginEvent event) {
        boolean result = false;
        try {
            logService.addLogEvent(event);
            result = true;
        } catch (Throwable ignored) {
            log.warn("Fail to add the log event" + event.getBuildId(), ignored);
        } finally {
            // 如果结果不对
            if (!result && event.getRetryTime() >= 0) {
                log.warn("Retry to add the log event " + event.getBuildId() + "time left:" + event.getRetryTime());
//                buildLogPrintService.dispatchEvent(
//                        new LogOriginEvent(
//                                event.getBuildId(),
//                                event.getLogs(),
//                                // 获取下一次事件的间隔
//                                event.getRetryTime() - 1,
//                                event.getNextDelayMills(event.getDelayMills())
//                        )
//                );
            }
        }
    }

    // 处理日志储存事件
    public void handleEvent(LogStorageEvent event) {
        boolean result = false;
        try {
            logService.addBatchLogEvent(event);
            result = true;
        } catch (Throwable ignored) {
            log.warn("Fail to add the log batch event " + event.getBuildId(), ignored);
        } finally {
            // 如果结果不对，那就重试
            if (!result && event.getRetryTime() >= 0) {
                log.warn("Retry to add the log batch event " + event.getBuildId() + "time left:" + event.getRetryTime());
//                buildLogPrintService.dispatchEvent(
//                        new LogStorageEvent(
//                                event.getBuildId(),
//                                event.getLogs(),
//                                // 获取下一次事件的间隔
//                                event.getRetryTime() - 1,
//                                event.getNextDelayMills(event.getDelayMills())
//                        )
//                );
            }
        }
    }

    // 处理日志状态事件
    public void handleEvent(LogStatusEvent event) {
        boolean result = false;
        try {
            logService.updateLogStatus(event);
            // #3089 当收到构建级别的状态刷新时，清理缓存并保存行数
            if (Strings.isBlank(event.getJobId()) && Strings.isBlank(event.getTag())) {
                indexService.flushLineNum2DB(event.getBuildId());
            }
            result = true;
        } catch (Throwable ignored) {
            log.warn("Fail to add the multi lines [" + event.getBuildId() + "|" + event.getRetryTime() + "]", ignored);
        } finally {
            // 如果结果不对，那就重试
            if (!result && event.getRetryTime() >= 0) {
                log.warn("Retry to add the multi lines " + event.getBuildId() + "time left:" + event.getRetryTime());

            }
        }
    }

}
