package cd.casic.pipeline.store.api.common;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.common.enums.StoreTypeEnum;
import cd.casic.pipeline.store.pojo.common.label.Label;
import cd.casic.pipeline.store.pojo.common.label.LabelRequest;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "OP_STORE_LABEL", description = "OP-STORE-标签")
@RestController
@RequestMapping("/op/store/label")
public interface OpLabelResource {

    @Operation(summary = "添加标签")
    @PostMapping("/types/{labelType}")
    CommonResult<Boolean> add(
            @Parameter(description = "类别", required = true)
            @PathVariable("labelType")
            StoreTypeEnum labelType,
            @Parameter(description = "标签信息请求报文体", required = true)
            LabelRequest labelRequest
    );

    @Operation(summary = "更新标签信息")
    @PutMapping("/types/{labelType}/ids/{id}")
    CommonResult<Boolean> update(
            @Parameter(description = "类别", required = true)
            @PathVariable("labelType")
            StoreTypeEnum labelType,
            @Parameter(description = "标签ID", required = true)
            @PathVariable("id")
            String id,
            @Parameter(description = "标签信息请求报文体", required = true)
            LabelRequest labelRequest
    );

    @Operation(summary = "获取所有标签信息")
    @GetMapping("/types/{labelType}")
    CommonResult<List<Label>> listAllLabels(
            @Parameter(description = "类别", required = true)
            @PathVariable("labelType")
            StoreTypeEnum labelType
    );

    @Operation(summary = "根据ID获取标签信息")
    @GetMapping("/{id}")
    CommonResult<Label> getLabelById(
            @Parameter(description = "标签ID", required = true)
            @RequestParam("id")
            String id
    );

    @Operation(summary = "根据ID删除标签信息")
    @DeleteMapping("/{id}")
    CommonResult<Boolean> deleteLabelById(
            @Parameter(description = "标签ID", required = true)
            @PathVariable("id")
            String id
    );
}