package cd.casic.pipeline.store.api.common;


import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.framework.commons.pojo.PageResult;
import cd.casic.pipeline.store.pojo.common.index.StoreIndexBaseInfo;
import cd.casic.pipeline.store.pojo.common.index.StoreIndexCreateRequest;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_USER_ID;


@Tag(name = "USER_STORE_INDEX_MANAGE", description = "研发商店指标管理")
@RestController
@RequestMapping("/user/store/indexs/manage")
public interface UserStoreIndexManageResource {

    @Operation(summary = "新增研发商店指标")
    @PostMapping("/add")
    CommonResult<Boolean> add(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "研发商店指标请求报文体", required = true)
            @Valid
            StoreIndexCreateRequest storeIndexCreateRequest
    );

    @Operation(summary = "删除研发商店指标")
    @DeleteMapping("/indexIds/{indexId}/delete")
    CommonResult<Boolean> delete(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "指标ID", required = true)
            @PathVariable("indexId")
            String indexId
    );

    @Operation(summary = "查询研发商店指标")
    @GetMapping("/list")
    PageResult<StoreIndexBaseInfo> list(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "查询关键字", required = false)
            @RequestParam("keyWords")
            String keyWords,
            @Parameter(description = "页码", required = true, example = "1")
            @RequestParam("page")
            int page,
            @Parameter(description = "每页数量", required = true, example = "10")
            @RequestParam("pageSize")
            int pageSize
    );
}