package cd.casic.pipeline.store.pojo.atom.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.text.MessageFormat;
import java.util.Arrays;
import java.util.List;

@Getter
@AllArgsConstructor
public enum AtomStatusEnum {
    INIT(0), // 初始化
    COMMITTING(1), // 提交中
    BUILDING(2), // 构建中
    BUILD_FAIL(3), // 构建失败
    TESTING(4), // 测试中
    AUDITING(5), // 审核中
    AUDIT_REJECT(6), // 审核驳回
    RELEASED(7), // 已发布
    GROUNDING_SUSPENSION(8), // 上架中止
    UNDERCARRIAGING(9), // 下架中
    UNDERCARRIAGED(10), // 已下架
    CODECCING(11), // 代码检查中
    CODECC_FAIL(12), // 代码检查失败
    TESTED(13); // 测试结束(仅分支测试使用)

    private final int status;

    public static AtomStatusEnum getAtomStatus(String name) {
        for (AtomStatusEnum enumObj : values()) {
            if (enumObj.name().equals(name)) {
                return enumObj;
            }
        }
        return null;
    }

    public static String getAtomStatus(int status) {
        for (AtomStatusEnum enumObj : values()) {
            if (enumObj.status == status) {
                return enumObj.name();
            }
        }
        return INIT.name();
    }

    public static List<Byte> getProcessingStatusList() {
        return Arrays.asList(
                (byte) INIT.status,
                (byte) COMMITTING.status,
                (byte) BUILDING.status,
                (byte) BUILD_FAIL.status,
                (byte) TESTING.status,
                (byte) AUDITING.status,
                (byte) CODECCING.status,
                (byte) CODECC_FAIL.status
        );
    }

    public String getI18n(String language) {
        return MessageFormat.format("STORE_ATOM_STATUS_" + this.name(),
                language);
    }
}