package cd.casic.ci.ticket;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.framework.commons.pojo.PageResult;
import cd.casic.ci.ticket.dal.pojo.*;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.security.Permission;
import java.util.List;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_USER_ID;
import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_USER_ID_DEFAULT_VALUE;

/**
 * @Author：mianbin
 * @Package：cd.casic.pipeline
 * @Project：ops-pro
 * @name：UserCredentialResource
 * @Date：2025/03/24 10:08
 * @Filename：UserCredentialResource
 * @description：Todo
 */
@RestController
@Tag(name = "服务-凭据资源")
@RequestMapping("/service/credentials")
public interface UserCredentialResource {
    @Operation(summary = "是否拥有创建凭据权限")
    @GetMapping("/{projectId}/hasCreatePermission")
    CommonResult<Boolean> hasCreatePermission(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID) String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId") String projectId
    );

    @Operation(summary = "新增凭据")
    @PostMapping("/{projectId}/")
    CommonResult<Boolean> create(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID) String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "凭据", required = true)
            @RequestBody CredentialCreate credential
    );

    @Operation(summary = "删除凭据")
    @DeleteMapping("/{projectId}/{credentialId}")
    CommonResult<Boolean> delete(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID) String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "凭据ID", required = true)
            @PathVariable("credentialId") String credentialId
    );

    @Operation(summary = "获取凭据列表")
    @GetMapping("/{projectId}/")
    PageResult<CredentialWithPermission> list(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID) String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "凭证类型列表，用逗号分隔", required = false)
            @RequestParam(value = "credentialTypes", required = false) String credentialTypesString,
            @Parameter(description = "第几页", required = false, example = "1")
            @RequestParam(value = "page", required = false) Integer page,
            @Parameter(description = "每页多少条", required = false, example = "20")
            @RequestParam(value = "pageSize", required = false) Integer pageSize,
            @Parameter(description = "关键字", required = false)
            @RequestParam(value = "keyword", required = false) String keyword
    );

    @Operation(summary = "获取拥有对应权限凭据列表")
    @GetMapping("/{projectId}/hasPermissionList")
    PageResult<Credential> hasPermissionList(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID) String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "凭证类型列表，用逗号分隔", required = false, example = "")
            @RequestParam(value = "credentialTypes", required = false) String credentialTypesString,
            @Parameter(description = "对应权限", required = true, example = "")
            @RequestParam("permission") Permission permission,
            @Parameter(description = "第几页", required = false, example = "1")
            @RequestParam(value = "page", required = false) Integer page,
            @Parameter(description = "每页多少条", required = false, example = "20")
            @RequestParam(value = "pageSize", required = false) Integer pageSize,
            @Parameter(description = "关键字", required = false)
            @RequestParam(value = "keyword", required = false) String keyword
    );

    @Operation(summary = "获取拥有对应权限凭据列表-不分页-插件UI调用")
    @GetMapping("/{projectId}/getHasPermissionList")
    CommonResult<List<Credential>> getHasPermissionList(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID) String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "凭证类型列表，用逗号分隔", required = false, example = "")
            @RequestParam(value = "credentialTypes", required = false) String credentialTypesString,
            @Parameter(description = "对应权限", required = true, example = "")
            @RequestParam("permission") Permission permission,
            @Parameter(description = "关键字", required = false)
            @RequestParam(value = "keyword", required = false) String keyword
    );

    @Operation(summary = "显示真实凭据")
    @GetMapping("/{projectId}/{credentialId}/show")
    CommonResult<CredentialWithPermission> show(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID) String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "凭据ID", required = true)
            @PathVariable("credentialId") String credentialId
    );


    @Operation(summary = "获取凭据以编辑")
    @GetMapping("/{projectId}/{credentialId}/")
    CommonResult<CredentialWithPermission> get(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID) String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "凭据ID", required = true)
            @PathVariable("credentialId") String credentialId
    );

    @Operation(summary = "编辑凭据")
    @PutMapping("/{projectId}/{credentialId}/")
    CommonResult<Boolean> edit(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID) String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "凭据ID", required = true)
            @PathVariable("credentialId") String credentialId,
            @Parameter(description = "凭据", required = true)
            @RequestBody CredentialUpdate credential
    );

    @Operation(summary = "编辑凭据设置凭据")
    @PutMapping("/{projectId}/{credentialId}/setting")
    CommonResult<Boolean> editSetting(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID) String userId,
            @Parameter(description = "项目ID", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "凭据ID", required = true)
            @PathVariable("credentialId") String credentialId,
            @Parameter(description = "凭据设置", required = true)
            @RequestBody CredentialSettingUpdate credentialSetting
    );
}
